@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,8 @@ class SegatexAlert: public QDialog
 {
 	Q_OBJECT
 public:
-	SegatexAlert(QWidget *parent = 0, const char *name = 0);
+	//SegatexAlert(QWidget *parent = 0, const char *name = 0);
+	SegatexAlert(QWidget *parent = 0);
 public slots:
 signals:
 protected:
