@@ -160,7 +160,7 @@ void Downloader::downloader_process(const Q3Url &url_for_fedora, QString version
 {
 	this->setEnabled(false);
 	process = new Q3Process(this);
-	process->addArgument("/root/segatex/downloader_program");
+	process->addArgument("/usr/share/segatex/downloader_program");
 	process->addArgument(url_for_fedora);
 	process->addArgument(version);
 
