@@ -59,7 +59,7 @@ void Editor::newFile()
 bool Editor::open()
 {
 	QString fileName =
-	    Q3FileDialog::getOpenFileName("/root/segatex", fileFilters, this);
+	    Q3FileDialog::getOpenFileName("/usr/share/segatex", fileFilters, this);
 	if (fileName.isEmpty())
 	return false;
 
@@ -90,7 +90,7 @@ bool Editor::save()
 
 bool Editor::saveAs()
 {
-	curFile = "/root/segatex/" + curFile; 
+	curFile = "/usr/share/segatex/" + curFile; 
 	QString fileName =
 	    Q3FileDialog::getSaveFileName(curFile, fileFilters, this);
 	if (fileName.isEmpty())
