@@ -90,6 +90,7 @@
 #include "semanage_core_port_process.h"
 #include "semanage_core_translation_process.h"
 #include "semanage_core_boolean_process.h"
+#include "semanage_core_permissive_process.h"
 #include "autorelabel.h"
 #include "policygeneration.h"
 #include "aureport.h"
@@ -136,6 +137,7 @@
 	semanage_core_port_process_o = 0;
 	semanage_core_translation_process_o = 0;
 	semanage_core_boolean_process_o = 0;
+	semanage_core_permissive_process_o = 0;
 	autorelabel_process_o = 0;
 	policygeneration_process_o = 0;
 	aureport_o = 0;
@@ -152,7 +154,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.72"));
+	setWindowTitle(tr("segatex-7.74"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
  }
@@ -203,7 +205,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
  }
 void MainWindow::open()
 {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/root/segatex",tr("Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv);;Any files(*)"));
+	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/usr/share/segatex",tr("Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv);;Any files(*)"));
 	if (!fileName.isEmpty()) {
 		QMdiSubWindow *existing = findMdiChild(fileName);
 		if (existing) {
@@ -247,7 +249,7 @@ void MainWindow::open()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.72</h2>"
+		tr("<h2>segatex-7.74</h2>"
 		"<p>Copyright &copy; 2007-2009"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -497,6 +499,11 @@ void MainWindow::createActions()
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(semanage_core_translation_process()));
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	semanage_core_permissive_processAct = new QAction(tr("semanage &permissive"), this);
+	semanage_core_permissive_processAct->setStatusTip(tr("Semanage permissive -a -d."));
+	connect(semanage_core_permissive_processAct, SIGNAL(activated()), this, SLOT(semanage_core_permissive_process()));
+	connect(semanage_core_permissive_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), this);
 	semanage_core_boolean_processAct->setStatusTip(tr("setsebool [-P] boolean value."));
 	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(semanage_core_boolean_process()));
@@ -588,6 +595,7 @@ void MainWindow::createMenus()
 	semanageMenu->addAction(semanage_core_port_processAct);
 	semanageMenu->addAction(semanage_core_translation_processAct);
 	semanageMenu->addAction(semanage_core_boolean_processAct);
+	semanageMenu->addAction(semanage_core_permissive_processAct);
 
 	relabelMenu = menuBar()->addMenu(tr("Re&label"));
 	relabelMenu->addAction(restoreconAct);
@@ -830,6 +838,15 @@ void MainWindow::semanage_core_boolean_process()
 	semanage_core_boolean_process_o->raise();
 	semanage_core_boolean_process_o->setActiveWindow();
 }
+void MainWindow::semanage_core_permissive_process()
+{
+	if(!semanage_core_permissive_process_o) {
+		semanage_core_permissive_process_o = new SemanageCorePermissiveProcess(this);
+	}
+	semanage_core_permissive_process_o->show();
+	semanage_core_permissive_process_o->raise();
+	semanage_core_permissive_process_o->setActiveWindow();
+}
 void MainWindow::autorelabel_process()
 {
 	if(!autorelabel_process_o) {
