@@ -167,7 +167,7 @@ void SemanageCoreLoginProcess::add_button_clicked_process(QString semanageEditLi
 {
 	semanageEditLineEdit_str_pp = "semanage login -a -s " + semanageEditLineEdit2_str + " -r " + semanageEditLineEdit6_str + " " + semanageEditLineEdit_str;
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/add_loggedin";
+        const char* make_module_file="/usr/share/segatex/semanage/add_loggedin";
         ofstream os_add;
         os_add.open(make_module_file);
         if(os_add){
@@ -198,7 +198,7 @@ void SemanageCoreLoginProcess::delete_button_clicked_process(QString semanageEdi
 {
 	semanageEditLineEdit_str_pp = "semanage login -d " + semanageEditLineEdit3_str;
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/delete_loggedin";
+        const char* make_module_file="/usr/share/segatex/semanage/delete_loggedin";
         ofstream os_delete;
         os_delete.open(make_module_file);
         if(os_delete){
@@ -228,7 +228,7 @@ void SemanageCoreLoginProcess::modify_button_clicked_process(QString semanageEdi
 {
 	semanageEditLineEdit_str_pp = "semanage login -m -s " + semanageEditLineEdit5_str + " -r " + semanageEditLineEdit7_str + " " + semanageEditLineEdit4_str;
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/modify_loggedin";
+        const char* make_module_file="/usr/share/segatex/semanage/modify_loggedin";
         ofstream os_modify;
         os_modify.open(make_module_file);
         if(os_modify){
@@ -259,7 +259,7 @@ void SemanageCoreLoginProcess::modify_button_clicked_process(QString semanageEdi
 void SemanageCoreLoginProcess::semanage_core_base_login_process()
 {
         #define PWD_BUF 8600
-        const char* semanage_login_list_file="/root/segatex/semanage/1_login";
+        const char* semanage_login_list_file="/usr/share/segatex/semanage/1_login";
         ofstream os;
         os.open(semanage_login_list_file);
         if(os){
@@ -284,7 +284,7 @@ void SemanageCoreLoginProcess::semanage_core_base_login_process()
 	os.close();
 	//outputfile_str_common = "login_list";
 
-        const char* semanage_user_list_file="/root/segatex/semanage/2_login";
+        const char* semanage_user_list_file="/usr/share/segatex/semanage/2_login";
         ofstream os2;
         os2.open(semanage_user_list_file);
         if(os2){
@@ -307,7 +307,7 @@ void SemanageCoreLoginProcess::semanage_core_base_login_process()
         }
 	os2.close();
 
-        const char* semanage_etc_passwd_list_file="/root/segatex/semanage/3_login";
+        const char* semanage_etc_passwd_list_file="/usr/share/segatex/semanage/3_login";
         ofstream os3;
         os3.open(semanage_etc_passwd_list_file);
         if(os3){
@@ -339,7 +339,7 @@ void SemanageCoreLoginProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
